Module jujutsu_lib::diff
source · Structs
Takes any number of inputs and finds regions that are them same between all
of them.
Enums
Functions
Diffs two slices of bytes. The returned diff hunks may be any length (may
span many lines or may be only part of a line). This currently uses
Histogram diff (or maybe something similar; I’m not sure I understood the
algorithm correctly). It first diffs lines in the input and then refines
the changed ranges at the word level.