Function jujutsu_lib::git::export_refs

source ·
pub fn export_refs(
    mut_repo: &mut MutableRepo,
    git_repo: &Repository
) -> Result<Vec<String>, GitExportError>
Reflect changes made in the Jujutsu repo compared to our current view of the Git repo in mut_repo.view().git_refs(). Returns a list of names of branches that failed to export.