Struct jujutsu_lib::matchers::IntersectionMatcher
source · pub struct IntersectionMatcher<'input> { /* private fields */ }Expand description
Matches paths that are matched by both input matchers.
pub struct IntersectionMatcher<'input> { /* private fields */ }Matches paths that are matched by both input matchers.