pub struct Operation {
pub view_id: ViewId,
pub parents: Vec<OperationId>,
pub metadata: OperationMetadata,
}Expand description
Represents an operation (transaction) on the repo view, just like how a Commit object represents an operation on the tree.
Operations and views are not meant to be exchanged between repos or users; they represent local state and history.
The operation history will almost always be linear. It will only have forks when parallel operations occurred. The parent is determined when the transaction starts. When the transaction commits, a lock will be taken and it will be checked that the current head of the operation graph is unchanged. If the current head has changed, there has been concurrent operation.
Fields
view_id: ViewIdparents: Vec<OperationId>metadata: OperationMetadataTrait Implementations
impl Eq for Operation
impl StructuralPartialEq for Operation