pub struct View {
pub head_ids: HashSet<CommitId>,
pub public_head_ids: HashSet<CommitId>,
pub branches: BTreeMap<String, BranchTarget>,
pub tags: BTreeMap<String, RefTarget>,
pub git_refs: BTreeMap<String, RefTarget>,
pub git_head: Option<RefTarget>,
pub wc_commit_ids: HashMap<WorkspaceId, CommitId>,
}Expand description
Represents the way the repo looks at a given time, just like how a Tree object represents how the file system looks at a given time.
Fields
head_ids: HashSet<CommitId>All head commits
public_head_ids: HashSet<CommitId>Heads of the set of public commits.
branches: BTreeMap<String, BranchTarget>git_refs: BTreeMap<String, RefTarget>git_head: Option<RefTarget>The commit the Git HEAD points to.
wc_commit_ids: HashMap<WorkspaceId, CommitId>Trait Implementations
impl Eq for View
impl StructuralPartialEq for View