RevsetExpression

Enum RevsetExpression 

pub enum RevsetExpression {
Show 24 variants None, All, Commits(Vec<CommitId>), Symbol(String), Children(Rc<RevsetExpression>), Ancestors { heads: Rc<RevsetExpression>, generation: Range<u32>, }, Range { roots: Rc<RevsetExpression>, heads: Rc<RevsetExpression>, generation: Range<u32>, }, DagRange { roots: Rc<RevsetExpression>, heads: Rc<RevsetExpression>, }, Heads(Rc<RevsetExpression>), Roots(Rc<RevsetExpression>), VisibleHeads, PublicHeads, Branches(String), RemoteBranches { branch_needle: String, remote_needle: String, }, Tags, GitRefs, GitHead, Filter(RevsetFilterPredicate), AsFilter(Rc<RevsetExpression>), Present(Rc<RevsetExpression>), NotIn(Rc<RevsetExpression>), Union(Rc<RevsetExpression>, Rc<RevsetExpression>), Intersection(Rc<RevsetExpression>, Rc<RevsetExpression>), Difference(Rc<RevsetExpression>, Rc<RevsetExpression>),
}

Variants



None



All



Commits(Vec<CommitId>)



Symbol(String)



Children(Rc<RevsetExpression>)



Ancestors

Fields

generation: Range<u32>


Range

Fields

generation: Range<u32>


DagRange



Heads(Rc<RevsetExpression>)



Roots(Rc<RevsetExpression>)



VisibleHeads



PublicHeads



Branches(String)



RemoteBranches

Fields

branch_needle: String
remote_needle: String


Tags



GitRefs



GitHead



Filter(RevsetFilterPredicate)



AsFilter(Rc<RevsetExpression>)

Marker for subtree that should be intersected as filter.



Present(Rc<RevsetExpression>)



NotIn(Rc<RevsetExpression>)



Union(Rc<RevsetExpression>, Rc<RevsetExpression>)



Intersection(Rc<RevsetExpression>, Rc<RevsetExpression>)



Difference(Rc<RevsetExpression>, Rc<RevsetExpression>)

Implementations

Source

impl RevsetExpression

pub fn none() -> Rc<RevsetExpression>

pub fn all() -> Rc<RevsetExpression>

pub fn symbol(value: String) -> Rc<RevsetExpression>

pub fn commit(commit_id: CommitId) -> Rc<RevsetExpression>

pub fn commits(commit_ids: Vec<CommitId>) -> Rc<RevsetExpression>

pub fn visible_heads() -> Rc<RevsetExpression>

pub fn public_heads() -> Rc<RevsetExpression>

pub fn branches(needle: String) -> Rc<RevsetExpression>

pub fn remote_branches( branch_needle: String, remote_needle: String, ) -> Rc<RevsetExpression>

pub fn tags() -> Rc<RevsetExpression>

pub fn git_refs() -> Rc<RevsetExpression>

pub fn git_head() -> Rc<RevsetExpression>

pub fn filter(predicate: RevsetFilterPredicate) -> Rc<RevsetExpression>

pub fn heads(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Commits in self that don’t have descendants in self.

pub fn roots(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Commits in self that don’t have ancestors in self.

pub fn parents(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Parents of self.

pub fn ancestors(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Ancestors of self, including self.

pub fn children(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Children of self.

pub fn descendants(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Descendants of self, including self.

pub fn dag_range_to( self: &Rc<RevsetExpression>, heads: &Rc<RevsetExpression>, ) -> Rc<RevsetExpression>

Commits that are descendants of self and ancestors of heads, both inclusive.

pub fn connected(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Connects any ancestors and descendants in the set by adding the commits between them.

pub fn range( self: &Rc<RevsetExpression>, heads: &Rc<RevsetExpression>, ) -> Rc<RevsetExpression>

Commits reachable from heads but not from self.

pub fn negated(self: &Rc<RevsetExpression>) -> Rc<RevsetExpression>

Commits that are not in self, i.e. the complement of self.

pub fn union( self: &Rc<RevsetExpression>, other: &Rc<RevsetExpression>, ) -> Rc<RevsetExpression>

Commits that are in self or in other (or both).

pub fn intersection( self: &Rc<RevsetExpression>, other: &Rc<RevsetExpression>, ) -> Rc<RevsetExpression>

Commits that are in self and in other.

pub fn minus( self: &Rc<RevsetExpression>, other: &Rc<RevsetExpression>, ) -> Rc<RevsetExpression>

Commits that are in self but not in other.

pub fn evaluate<'repo>( &self, repo: &'repo dyn Repo, workspace_ctx: Option<&RevsetWorkspaceContext<'_>>, ) -> Result<Box<dyn Revset<'repo> + 'repo>, RevsetError>