Struct jujutsu_lib::store::Store
source · pub struct Store { /* private fields */ }Expand description
Wraps the low-level backend and makes it return more convenient types. Also adds the root commit and adds caching.
pub struct Store { /* private fields */ }Wraps the low-level backend and makes it return more convenient types. Also adds the root commit and adds caching.