pub struct Transaction { /* private fields */ }

Implementations

Writes the transaction to the operation store and publishes it.

Writes the transaction to the operation store, but does not publish it. That means that a repo can be loaded at the operation, but the operation will not be seen when loading the repo at head.