Struct jujutsu_lib::working_copy::LockedWorkingCopy
source · pub struct LockedWorkingCopy<'a> { /* private fields */ }Expand description
A working copy that’s locked on disk. The lock is held until you call
finish() or discard().
Implementations
sourceimpl LockedWorkingCopy<'_>
impl LockedWorkingCopy<'_>
sourcepub fn old_operation_id(&self) -> &OperationId
pub fn old_operation_id(&self) -> &OperationId
The operation at the time the lock was taken
sourcepub fn old_tree_id(&self) -> &TreeId
pub fn old_tree_id(&self) -> &TreeId
The tree at the time the lock was taken