pub struct Workspace { /* private fields */ }
Represents a workspace, i.e. what’s typically the .jj/ directory and its parent.

Implementations

Initializes a workspace with a new Git backend in .jj/git/ (bare Git repo)

Initializes a workspace with an existing Git backend at the specified path