Module jujutsu_lib::git
source · Structs
Enums
Functions
Reflect changes made in the Jujutsu repo compared to our current view of the
Git repo in
mut_repo.view().git_refs(). Returns a list of names of
branches that failed to export.Reflect changes made in the underlying Git repo in the Jujutsu repo.