pub struct MutableRepo { /* private fields */ }

Implementations

Record a commit as having been rewritten in this transaction. This record is used by rebase_descendants().

Rewritten commits don’t have to be recorded here. This is just a convenient place to record it. It won’t matter after the transaction has been committed.

Record a commit as having been abandoned in this transaction. This record is used by rebase_descendants().

Abandoned commits don’t have to be recorded here. This is just a convenient place to record it. It won’t matter after the transaction has been committed.

Creates a DescendantRebaser to rebase descendants of the recorded rewritten and abandoned commits.