Struct jujutsu_lib::transaction::Transaction
source · pub struct Transaction { /* private fields */ }Implementations
sourceimpl Transaction
impl Transaction
pub fn new(
mut_repo: MutableRepo,
user_settings: &UserSettings,
description: &str
) -> Transaction
pub fn base_repo(&self) -> &ReadonlyRepo
pub fn set_tag(&mut self, key: String, value: String)
pub fn repo(&self) -> &MutableRepo
pub fn mut_repo(&mut self) -> &mut MutableRepo
pub fn merge_operation(&mut self, other_op: Operation)
sourcepub fn commit(self) -> Arc<ReadonlyRepo>
pub fn commit(self) -> Arc<ReadonlyRepo>
Writes the transaction to the operation store and publishes it.
sourcepub fn write(self) -> UnpublishedOperation
pub fn write(self) -> UnpublishedOperation
Writes the transaction to the operation store, but does not publish it. That means that a repo can be loaded at the operation, but the operation will not be seen when loading the repo at head.