Struct jujutsu_lib::workspace::Workspace
source · pub struct Workspace { /* private fields */ }Expand description
Represents a workspace, i.e. what’s typically the .jj/ directory and its parent.
Implementations
sourceimpl Workspace
impl Workspace
pub fn init_local(
user_settings: &UserSettings,
workspace_root: &Path
) -> Result<(Self, Arc<ReadonlyRepo>), WorkspaceInitError>
sourcepub fn init_internal_git(
user_settings: &UserSettings,
workspace_root: &Path
) -> Result<(Self, Arc<ReadonlyRepo>), WorkspaceInitError>
pub fn init_internal_git(
user_settings: &UserSettings,
workspace_root: &Path
) -> Result<(Self, Arc<ReadonlyRepo>), WorkspaceInitError>
Initializes a workspace with a new Git backend in .jj/git/ (bare Git repo)
sourcepub fn init_external_git(
user_settings: &UserSettings,
workspace_root: &Path,
git_repo_path: &Path
) -> Result<(Self, Arc<ReadonlyRepo>), WorkspaceInitError>
pub fn init_external_git(
user_settings: &UserSettings,
workspace_root: &Path,
git_repo_path: &Path
) -> Result<(Self, Arc<ReadonlyRepo>), WorkspaceInitError>
Initializes a workspace with an existing Git backend at the specified path